==> idris-1.3.4-232-riscv64.pkg.tar.zst: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.4
visibility:           public
id:                   idris-1.3.4-18VDLXZpuv0Ar3uuBJIQUM
key:                  idris-1.3.4-18VDLXZpuv0Ar3uuBJIQUM
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  bda1a22687621655a2a37c7b8f7879db
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.2.8/site-local/idris-1.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/idris-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.4-18VDLXZpuv0Ar3uuBJIQUM
extra-libraries:      gmp
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    ansi-wl-pprint-0.6.9-9ctTtDT9IMdHR9rtwZQvOW array-0.5.4.0
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj binary-0.8.9.0
    blaze-html-0.9.2.0-83dGvLlliMHJ0KNCx2IkOp
    blaze-markup-0.8.3.0-6XpAp6edGaj5nW8WYpqqy9 bytestring-0.11.4.0
    cheapskate-0.1.1.2-GNZwKxNDvWe3uKnGvBJQ5F
    code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2
    fingertree-0.1.5.0-AJVqKDHNwtMCVCJkdhePc5
    fsnotify-0.4.0.0-HbXdbjZ1b60AMG4U0U7HN9 haskeline-0.8.2
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    libffi-0.2.1-LccIAuoU8yrBMDFxV9AXvd
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 pretty-1.1.3.6
    process-1.6.16.0 regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    split-0.2.5-L5qB0eGVSdY6HJmwsU4RMl
    terminal-size-0.3.4-7GJNKkuDjwr8c9rYP2Bu9E text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    uniplate-1.6.13-1TlVKfWXnEq89IfsWzj5q8 unix-2.7.2.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vector-binary-instances-0.2.5.2-JbK0GaywNsMEVgxrIlAP6k
    zip-archive-0.4.3.2-6oIc3L9nVJJUpVNmPG3PI

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> idris-1.3.4-318.1-riscv64.pkg.tar.zst: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 idris
version:              1.3.4
visibility:           public
id:                   idris-1.3.4-8I2FsSW72Lc7zN2YvYKRJQ
key:                  idris-1.3.4-8I2FsSW72Lc7zN2YvYKRJQ
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  7bc00a73fbf558e50006aeddc9f56847
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.4.8/site-local/idris-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/idris-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/idris-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.4-8I2FsSW72Lc7zN2YvYKRJQ
extra-libraries:      gmp
depends:
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO
    ansi-wl-pprint-0.6.9-5BK1jGC8Azm6PTKOUvlx5t array-0.5.4.0
    async-2.2.5-CjCuZi34HovIas1x5o0XNl base-4.17.2.1
    base64-bytestring-1.2.1.0-51qKIpJ73TV1AKDjoSOLuj binary-0.8.9.1
    blaze-html-0.9.2.0-LTgARzkQmuR7wd3WENC7Bl
    blaze-markup-0.8.3.0-HvClWyZZzWCEWnziM7XRoL bytestring-0.11.5.3
    cheapskate-0.1.1.2-3LYGuJNtlPgEWD00MwORTH
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    fingertree-0.1.5.0-8zfmULtU8NoJgtF8Ki79uP
    fsnotify-0.4.1.0-2RFXZURRVqjFG87fpPXV4g haskeline-0.8.2
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    libffi-0.2.1-DPsLfzr2gvt1V2FBULxP58
    megaparsec-9.6.1-6pqHq8BNT2333chbXCRu9H mtl-2.2.2
    network-3.1.4.0-AQGzws0tmah75qbsifMDHb
    optparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav pretty-1.1.3.6
    process-1.6.18.0 regex-tdfa-1.3.2.4-LXwWfM9riXbAuaKHkk8lra
    safe-0.3.21-9t18UaHoT5jA6SQBJagYvS
    split-0.2.5-2HeD4Nuqed4MnDSfwehTU
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-FPxTMXtfUHnEXogiyqcBmu
    unix-2.7.3 unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16
    vector-binary-instances-0.2.5.2-2Sz6OO6xvkq4Mvf87zCoPm
    zip-archive-0.4.3.2-HzvXG4V7Sj2B7jMVA9X1GM

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
